[Buildbot-commits] buildbot/buildbot/process base.py,1.53,1.54

Brian Warner warner at users.sourceforge.net
Wed May 18 07:49:32 UTC 2005


Update of /cvsroot/buildbot/buildbot/buildbot/process
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv9801/buildbot/process

Modified Files:
	base.py 
Log Message:
Revision: arch at buildbot.sf.net--2004/buildbot--dev--0--patch-209
Creator:  Brian Warner <warner at monolith.lothar.com>

rename Change(tag=) to branch=

	* buildbot/changes/changes.py: rename tag= to branch=, since
	that's how we're using it, and my design for the upcoming "build a
	specific branch" feature wants it. also, tag= was too CVS-centric
	* buildbot/changes/mail.py (parseSyncmail): same
	* buildbot/process/base.py (Build.isBranchImportant): same
	* buildbot/test/test_mailparse.py (Test3.testMsgS4): same
	* docs/buildbot.texinfo (Attributes of Changes): same

	* NEWS: update tag=, update for upcoming release


Index: base.py
===================================================================
RCS file: /cvsroot/buildbot/buildbot/buildbot/process/base.py,v
retrieving revision 1.53
retrieving revision 1.54
diff -u -d -r1.53 -r1.54
--- base.py	18 May 2005 00:51:03 -0000	1.53
+++ base.py	18 May 2005 07:49:30 -0000	1.54
@@ -107,12 +107,12 @@
         """
         return True
 
-    def isTagImportant(self, tag):
-        """I return True if the given tag is important enough to trigger a
+    def isBranchImportant(self, branch):
+        """I return True if the given branch is important enough to trigger a
         rebuild, False if it should be ignored. Override me to ignore
-        unimporant tags. The timer is not restarted, so a checkout may occur
-        in the middle of a set of changes marked 'unimportant'. Also, the
-        checkout may or may not pick up the 'unimportant' changes."""
+        unimportant branches. The timer is not restarted, so a checkout may
+        occur in the middle of a set of changes marked 'unimportant'. Also,
+        the checkout may or may not pick up the 'unimportant' changes."""
         return True
      
     def bumpMaxChangeNumber(self, change):
@@ -129,11 +129,11 @@
         @type  change: L{buildbot.changes.changes.Change}
         """
         # for a change to be important, it needs to be with an important
         # tag and it need to contain an important file
 
         important = 0
 
-        if self.isTagImportant(change.tag):
+        if self.isBranchImportant(change.branch):
             for filename in change.files:
                 if self.isFileImportant(filename):
                     important = 1
@@ -129,11 +129,11 @@
         """
         # for a change to be important, it needs to be with an important
-        # tag and it need to contain an important file
+        # branch and it need to contain an important file
 
         important = 0





More information about the Commits mailing list